{
  description = "Radarr";

  inputs = {
    nixpkgs = {
      url = "nixpkgs/nixos-unstable";
    };
  };

  outputs = { self, nixpkgs }@inputs:
    let
      system = "x86_64-linux";
      pkgs = import nixpkgs {
        inherit system;
        overlays = [
          (
            self: super:
              {
                radarr =
                  let
                    version = "4.1.0.6175";
                    os = "linux";
                    arch = "x64";
                  in
                  super.radarr.overrideAttrs (old: {
                    inherit version;
                    src = builtins.fetchurl {
                      url = "https://github.com/Radarr/Radarr/releases/download/v${version}/Radarr.master.${version}.${os}-core-${arch}.tar.gz";
                      sha256 = "sha256:0b3kb7wrh3s3kr5phb2f8flzchnj19i95dd434gdzi551w34536y";
                    };
                  });
              }
          )
        ];
      };
    in
    {
      packages.${system}.default = pkgs.dockerTools.buildLayeredImage
        {
          name = "radarr";
          tag = "latest";
          maxLayers = 2;
          contents = [
            pkgs.cacert
            pkgs.coreutils-full
            pkgs.bash
            pkgs.util-linux
          ];
          fakeRootCommands = ''
            mkdir /config
            mkdir /media
            chown 5000:5000 /config
            chown 5000:5000 /media
          '';
          config = {
            Cmd = [
              "${pkgs.radarr}/bin/Radarr"
              "-nobrowser"
              "-data=/config"
            ];
            User = "5000:5000";
            Env = [
              "COMPlus_EnableDiagnostics=0"
              "XDG_CONFIG_HOME=/config/xdg"
            ];
            ExposedPorts = {
              "7878/tcp" = { };
            };
            Volumes = {
              "/config" = { };
              "/media" = { };
            };
          };
        };
    };
}
